]> git.rkrishnan.org Git - tahoe-lafs/tahoe-lafs.git/blobdiff - setup.py
docs: update README, mv it to README.txt, update setup.py
[tahoe-lafs/tahoe-lafs.git] / setup.py
index 88536d125a5d4ce3f8d6a6b69a0a298197188a6b..b131188ab4a5b482a089b316f396dfcf0381059e 100644 (file)
--- a/setup.py
+++ b/setup.py
@@ -1,9 +1,9 @@
 #! /usr/bin/env python
 # -*- coding: utf-8 -*-
 
# Allmydata Tahoe -- secure, distributed storage grid
 #
-# Copyright © 2008-2009 Allmydata, Inc.
+# Copyright © 2008-2010 Allmydata, Inc.
 #
 # This file is part of Tahoe-LAFS.
 #
@@ -98,16 +98,6 @@ trove_classifiers=[
     ]
 
 
-LONG_DESCRIPTION=\
-"""Welcome to the Tahoe project, a secure, decentralized, fault-tolerant
-filesystem.  All of the source code is available under a Free Software, Open
-Source licence.
-
-This filesystem is encrypted and spread over multiple peers in such a way that
-it remains available even when some of the peers are unavailable,
-malfunctioning, or malicious."""
-
-
 setup_requires = []
 
 # The darcsver command from the darcsver plugin is needed to initialize the
@@ -359,11 +349,11 @@ if version:
 
 setup(name=APPNAME,
       description='secure, decentralized, fault-tolerant filesystem',
-      long_description=LONG_DESCRIPTION,
-      author='the allmydata.org Tahoe project',
+      long_description=open('README.txt', 'rU').read(),
+      author='the Tahoe-LAFS project',
       author_email='tahoe-dev@allmydata.org',
-      url='http://allmydata.org/',
-      license='GNU GPL',
+      url='http://tahoe-lafs.org/',
+      license='GNU GPL', # see README.txt -- there is an alternative licence
       cmdclass={"show_supportlib": ShowSupportLib,
                 "show_pythonpath": ShowPythonPath,
                 "run_with_pythonpath": RunWithPythonPath,
@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
-# Allmydata Tahoe -- secure, distributed storage grid
+# Tahoe-LAFS -- secure, distributed storage grid
 #